aboutsummaryrefslogtreecommitdiffstats
path: root/doc/packet-PROTOABBREV.c
diff options
context:
space:
mode:
Diffstat (limited to 'doc/packet-PROTOABBREV.c')
-rw-r--r--doc/packet-PROTOABBREV.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/doc/packet-PROTOABBREV.c b/doc/packet-PROTOABBREV.c
index 1e4c9975d6..c1aaba8d36 100644
--- a/doc/packet-PROTOABBREV.c
+++ b/doc/packet-PROTOABBREV.c
@@ -97,7 +97,7 @@ dissect_PROTOABBREV(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
*/
/* Check that there's enough data */
- if (tvb_length(tvb) < PROTOABBREV_MIN_LENGTH)
+ if (tvb_reported_length(tvb) < PROTOABBREV_MIN_LENGTH)
return 0;
/* Fetch some values from the packet header using tvb_get_*(). If these
@@ -181,8 +181,8 @@ dissect_PROTOABBREV(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
* README.dissector for more information. */
/* Return the amount of data this dissector was able to dissect (which may
- * or may not be the entire packet as we return here). */
- return tvb_length(tvb);
+ * or may not be the total captured packet as we return here). */
+ return tvb_captured_length(tvb);
}
/* Register the protocol with Wireshark.